var namespacegko =
[
    [ "batch", null, [
      [ "log", "namespacegko_1_1batch_1_1log.html", "namespacegko_1_1batch_1_1log" ],
      [ "BatchLinOp", "classgko_1_1batch_1_1BatchLinOp.html", "classgko_1_1batch_1_1BatchLinOp" ],
      [ "BatchLinOpFactory", "classgko_1_1batch_1_1BatchLinOpFactory.html", null ],
      [ "EnableBatchLinOp", "classgko_1_1batch_1_1EnableBatchLinOp.html", null ],
      [ "MultiVector", "classgko_1_1batch_1_1MultiVector.html", "classgko_1_1batch_1_1MultiVector" ],
      [ "EnableDefaultBatchLinOpFactory", "group__BatchLinOp.html#gaa62d516d392c16b9580dd0d8067a0041", null ]
    ] ],
    [ "matrix", "namespacegko_1_1matrix.html", "namespacegko_1_1matrix" ],
    [ "experimental", null, [
      [ "mpi", "namespacegko_1_1experimental_1_1mpi.html", "namespacegko_1_1experimental_1_1mpi" ],
      [ "distributed", "namespacegko_1_1experimental_1_1distributed.html", "namespacegko_1_1experimental_1_1distributed" ],
      [ "reorder", "namespacegko_1_1experimental_1_1reorder.html", "namespacegko_1_1experimental_1_1reorder" ]
    ] ],
    [ "name_demangling", "namespacegko_1_1name__demangling.html", [
      [ "get_dynamic_type", "namespacegko_1_1name__demangling.html#a7469320f9401df05fcad48027569cef0", null ],
      [ "get_static_type", "namespacegko_1_1name__demangling.html#a305c6bc422a3babdd1179db5b2859ae3", null ]
    ] ],
    [ "accessor", "namespacegko_1_1accessor.html", "namespacegko_1_1accessor" ],
    [ "xstd", "namespacegko_1_1xstd.html", "namespacegko_1_1xstd" ],
    [ "multigrid", "namespacegko_1_1multigrid.html", "namespacegko_1_1multigrid" ],
    [ "factorization", "namespacegko_1_1factorization.html", "namespacegko_1_1factorization" ],
    [ "log", "namespacegko_1_1log.html", "namespacegko_1_1log" ],
    [ "stop", "namespacegko_1_1stop.html", "namespacegko_1_1stop" ],
    [ "preconditioner", "namespacegko_1_1preconditioner.html", "namespacegko_1_1preconditioner" ],
    [ "reorder", "namespacegko_1_1reorder.html", "namespacegko_1_1reorder" ],
    [ "solver", "namespacegko_1_1solver.html", "namespacegko_1_1solver" ],
    [ "syn", "namespacegko_1_1syn.html", "namespacegko_1_1syn" ],
    [ "AbstractFactory", "classgko_1_1AbstractFactory.html", "classgko_1_1AbstractFactory" ],
    [ "EnableDefaultFactory", "classgko_1_1EnableDefaultFactory.html", "classgko_1_1EnableDefaultFactory" ],
    [ "enable_parameters_type", "classgko_1_1enable__parameters__type.html", "classgko_1_1enable__parameters__type" ],
    [ "deferred_factory_parameter", "classgko_1_1deferred__factory__parameter.html", "classgko_1_1deferred__factory__parameter" ],
    [ "array", "classgko_1_1array.html", "classgko_1_1array" ],
    [ "batch_dim", "structgko_1_1batch__dim.html", "structgko_1_1batch__dim" ],
    [ "bfloat16", "classgko_1_1bfloat16.html", null ],
    [ "BlockOperator", "classgko_1_1BlockOperator.html", "classgko_1_1BlockOperator" ],
    [ "Combination", "classgko_1_1Combination.html", "classgko_1_1Combination" ],
    [ "Composition", "classgko_1_1Composition.html", "classgko_1_1Composition" ],
    [ "UseComposition", "classgko_1_1UseComposition.html", "classgko_1_1UseComposition" ],
    [ "nvidia_device", "classgko_1_1nvidia__device.html", null ],
    [ "amd_device", "classgko_1_1amd__device.html", null ],
    [ "device_matrix_data", "classgko_1_1device__matrix__data.html", "classgko_1_1device__matrix__data" ],
    [ "dim", "structgko_1_1dim.html", "structgko_1_1dim" ],
    [ "dim&lt; 1u, DimensionType &gt;", "structgko_1_1dim_3_011u_00_01DimensionType_01_4.html", null ],
    [ "Error", "classgko_1_1Error.html", "classgko_1_1Error" ],
    [ "NotImplemented", "classgko_1_1NotImplemented.html", "classgko_1_1NotImplemented" ],
    [ "NotCompiled", "classgko_1_1NotCompiled.html", "classgko_1_1NotCompiled" ],
    [ "NotSupported", "classgko_1_1NotSupported.html", "classgko_1_1NotSupported" ],
    [ "MpiError", "classgko_1_1MpiError.html", "classgko_1_1MpiError" ],
    [ "CudaError", "classgko_1_1CudaError.html", "classgko_1_1CudaError" ],
    [ "CublasError", "classgko_1_1CublasError.html", "classgko_1_1CublasError" ],
    [ "CurandError", "classgko_1_1CurandError.html", "classgko_1_1CurandError" ],
    [ "CusparseError", "classgko_1_1CusparseError.html", "classgko_1_1CusparseError" ],
    [ "CufftError", "classgko_1_1CufftError.html", "classgko_1_1CufftError" ],
    [ "HipError", "classgko_1_1HipError.html", "classgko_1_1HipError" ],
    [ "HipblasError", "classgko_1_1HipblasError.html", "classgko_1_1HipblasError" ],
    [ "HiprandError", "classgko_1_1HiprandError.html", "classgko_1_1HiprandError" ],
    [ "HipsparseError", "classgko_1_1HipsparseError.html", "classgko_1_1HipsparseError" ],
    [ "HipfftError", "classgko_1_1HipfftError.html", "classgko_1_1HipfftError" ],
    [ "MetisError", "classgko_1_1MetisError.html", "classgko_1_1MetisError" ],
    [ "DimensionMismatch", "classgko_1_1DimensionMismatch.html", "classgko_1_1DimensionMismatch" ],
    [ "BadDimension", "classgko_1_1BadDimension.html", "classgko_1_1BadDimension" ],
    [ "BlockSizeError", "classgko_1_1BlockSizeError.html", "classgko_1_1BlockSizeError" ],
    [ "ValueMismatch", "classgko_1_1ValueMismatch.html", "classgko_1_1ValueMismatch" ],
    [ "AllocationError", "classgko_1_1AllocationError.html", "classgko_1_1AllocationError" ],
    [ "OutOfBoundsError", "classgko_1_1OutOfBoundsError.html", "classgko_1_1OutOfBoundsError" ],
    [ "OverflowError", "classgko_1_1OverflowError.html", "classgko_1_1OverflowError" ],
    [ "StreamError", "classgko_1_1StreamError.html", "classgko_1_1StreamError" ],
    [ "KernelNotFound", "classgko_1_1KernelNotFound.html", "classgko_1_1KernelNotFound" ],
    [ "UnsupportedMatrixProperty", "classgko_1_1UnsupportedMatrixProperty.html", "classgko_1_1UnsupportedMatrixProperty" ],
    [ "InvalidStateError", "classgko_1_1InvalidStateError.html", "classgko_1_1InvalidStateError" ],
    [ "Operation", "classgko_1_1Operation.html", "classgko_1_1Operation" ],
    [ "Executor", "classgko_1_1Executor.html", "classgko_1_1Executor" ],
    [ "executor_deleter", "classgko_1_1executor__deleter.html", "classgko_1_1executor__deleter" ],
    [ "executor_deleter&lt; T[]&gt;", "classgko_1_1executor__deleter_3_01T_0f_0e_4.html", null ],
    [ "OmpExecutor", "classgko_1_1OmpExecutor.html", "classgko_1_1OmpExecutor" ],
    [ "ReferenceExecutor", "classgko_1_1ReferenceExecutor.html", "classgko_1_1ReferenceExecutor" ],
    [ "CudaExecutor", "classgko_1_1CudaExecutor.html", "classgko_1_1CudaExecutor" ],
    [ "HipExecutor", "classgko_1_1HipExecutor.html", "classgko_1_1HipExecutor" ],
    [ "DpcppExecutor", "classgko_1_1DpcppExecutor.html", "classgko_1_1DpcppExecutor" ],
    [ "truncated", "classgko_1_1truncated.html", null ],
    [ "half", "classgko_1_1half.html", null ],
    [ "index_set", "classgko_1_1index__set.html", "classgko_1_1index__set" ],
    [ "LinOp", "classgko_1_1LinOp.html", "classgko_1_1LinOp" ],
    [ "LinOpFactory", "classgko_1_1LinOpFactory.html", null ],
    [ "Transposable", "classgko_1_1Transposable.html", "classgko_1_1Transposable" ],
    [ "Permutable", "classgko_1_1Permutable.html", "classgko_1_1Permutable" ],
    [ "ReadableFromMatrixData", "classgko_1_1ReadableFromMatrixData.html", "classgko_1_1ReadableFromMatrixData" ],
    [ "WritableToMatrixData", "classgko_1_1WritableToMatrixData.html", "classgko_1_1WritableToMatrixData" ],
    [ "Preconditionable", "classgko_1_1Preconditionable.html", "classgko_1_1Preconditionable" ],
    [ "DiagonalLinOpExtractable", "classgko_1_1DiagonalLinOpExtractable.html", "classgko_1_1DiagonalLinOpExtractable" ],
    [ "DiagonalExtractable", "classgko_1_1DiagonalExtractable.html", "classgko_1_1DiagonalExtractable" ],
    [ "AbsoluteComputable", "classgko_1_1AbsoluteComputable.html", "classgko_1_1AbsoluteComputable" ],
    [ "EnableAbsoluteComputation", "classgko_1_1EnableAbsoluteComputation.html", "classgko_1_1EnableAbsoluteComputation" ],
    [ "ScaledIdentityAddable", "classgko_1_1ScaledIdentityAddable.html", "classgko_1_1ScaledIdentityAddable" ],
    [ "EnableLinOp", "classgko_1_1EnableLinOp.html", null ],
    [ "machine_topology", "classgko_1_1machine__topology.html", "classgko_1_1machine__topology" ],
    [ "cpx_real_type", "structgko_1_1cpx__real__type.html", "structgko_1_1cpx__real__type" ],
    [ "default_converter", "structgko_1_1default__converter.html", "structgko_1_1default__converter" ],
    [ "matrix_assembly_data", "classgko_1_1matrix__assembly__data.html", "classgko_1_1matrix__assembly__data" ],
    [ "matrix_data_entry", "structgko_1_1matrix__data__entry.html", null ],
    [ "matrix_data", "structgko_1_1matrix__data.html", "structgko_1_1matrix__data" ],
    [ "Allocator", "classgko_1_1Allocator.html", null ],
    [ "CpuAllocatorBase", "classgko_1_1CpuAllocatorBase.html", null ],
    [ "CudaAllocatorBase", "classgko_1_1CudaAllocatorBase.html", null ],
    [ "HipAllocatorBase", "classgko_1_1HipAllocatorBase.html", null ],
    [ "CpuAllocator", "classgko_1_1CpuAllocator.html", null ],
    [ "CudaAllocator", "classgko_1_1CudaAllocator.html", null ],
    [ "CudaAsyncAllocator", "classgko_1_1CudaAsyncAllocator.html", "classgko_1_1CudaAsyncAllocator" ],
    [ "CudaUnifiedAllocator", "classgko_1_1CudaUnifiedAllocator.html", null ],
    [ "CudaHostAllocator", "classgko_1_1CudaHostAllocator.html", null ],
    [ "HipAllocator", "classgko_1_1HipAllocator.html", null ],
    [ "HipAsyncAllocator", "classgko_1_1HipAsyncAllocator.html", null ],
    [ "HipUnifiedAllocator", "classgko_1_1HipUnifiedAllocator.html", null ],
    [ "HipHostAllocator", "classgko_1_1HipHostAllocator.html", null ],
    [ "Perturbation", "classgko_1_1Perturbation.html", "classgko_1_1Perturbation" ],
    [ "PolymorphicObject", "classgko_1_1PolymorphicObject.html", "classgko_1_1PolymorphicObject" ],
    [ "EnablePolymorphicObject", "classgko_1_1EnablePolymorphicObject.html", null ],
    [ "EnablePolymorphicAssignment", "classgko_1_1EnablePolymorphicAssignment.html", null ],
    [ "EnableCreateMethod", "classgko_1_1EnableCreateMethod.html", null ],
    [ "span", "structgko_1_1span.html", "structgko_1_1span" ],
    [ "local_span", "structgko_1_1local__span.html", "structgko_1_1local__span" ],
    [ "range", "classgko_1_1range.html", "classgko_1_1range" ],
    [ "scoped_device_id_guard", "classgko_1_1scoped__device__id__guard.html", "classgko_1_1scoped__device__id__guard" ],
    [ "segmented_array", "structgko_1_1segmented__array.html", "structgko_1_1segmented__array" ],
    [ "cuda_stream", "classgko_1_1cuda__stream.html", "classgko_1_1cuda__stream" ],
    [ "hip_stream", "classgko_1_1hip__stream.html", "classgko_1_1hip__stream" ],
    [ "err", "structgko_1_1err.html", null ],
    [ "time_point", "classgko_1_1time__point.html", null ],
    [ "Timer", "classgko_1_1Timer.html", "classgko_1_1Timer" ],
    [ "CpuTimer", "classgko_1_1CpuTimer.html", "classgko_1_1CpuTimer" ],
    [ "CudaTimer", "classgko_1_1CudaTimer.html", "classgko_1_1CudaTimer" ],
    [ "HipTimer", "classgko_1_1HipTimer.html", "classgko_1_1HipTimer" ],
    [ "DpcppTimer", "classgko_1_1DpcppTimer.html", "classgko_1_1DpcppTimer" ],
    [ "are_all_integral", "structgko_1_1are__all__integral.html", null ],
    [ "are_all_integral&lt; First, Args... &gt;", "structgko_1_1are__all__integral_3_01First_00_01Args_8_8_8_01_4.html", null ],
    [ "precision_reduction", "classgko_1_1precision__reduction.html", "classgko_1_1precision__reduction" ],
    [ "ptr_param", "classgko_1_1ptr__param.html", "classgko_1_1ptr__param" ],
    [ "null_deleter", "classgko_1_1null__deleter.html", "classgko_1_1null__deleter" ],
    [ "null_deleter&lt; T[]&gt;", "classgko_1_1null__deleter_3_01T_0f_0e_4.html", null ],
    [ "version", "structgko_1_1version.html", "structgko_1_1version" ],
    [ "version_info", "classgko_1_1version__info.html", "classgko_1_1version__info" ],
    [ "stopping_status", "classgko_1_1stopping__status.html", "classgko_1_1stopping__status" ],
    [ "default_precision", "namespacegko.html#a89637c833af7ae805802226d97cebebf", null ],
    [ "EnableDefaultLinOpFactory", "group__LinOp.html#ga33a81667a26919fae5864bbd9ca302ad", null ],
    [ "float16", "namespacegko.html#af1e94db06aba818c1db32a2a683836c9", null ],
    [ "float32", "namespacegko.html#af14be891fe28c2fb9ad22509ba49b8f4", null ],
    [ "float64", "namespacegko.html#a86e94f8a1bcd1b4d7fd970383c138a30", null ],
    [ "full_precision", "namespacegko.html#a1a74b54097c5a16d13644658efa18de0", null ],
    [ "highest_precision", "namespacegko.html#a429e949bc6e25abb24aded48e901d55d", null ],
    [ "increase_precision", "namespacegko.html#ad6883fe3514ba0b125a4fc26c94ea9d1", null ],
    [ "int16", "namespacegko.html#a1c5858448a3585731f33870694860aff", null ],
    [ "int32", "namespacegko.html#a16bd14c10900eb804d784908d8aab5ab", null ],
    [ "int64", "namespacegko.html#a913ec044df518649fa5a891f8dffae34", null ],
    [ "int8", "namespacegko.html#a7ff694002fd7739ee5c4c03f4159c3ca", null ],
    [ "is_complex_or_scalar_s", "namespacegko.html#abf707c1057eb7f959355ab06990441a8", null ],
    [ "is_complex_s", "namespacegko.html#a700d12db3a341bb7a46bede49e1d6715", null ],
    [ "next_precision", "namespacegko.html#aee37f85b217e5e26fe64207d41fa4bac", null ],
    [ "next_precision_base", "namespacegko.html#a2c2416a808014f8b0647d5e4ba42a735", null ],
    [ "previous_precision", "namespacegko.html#ada2119004771922e8f7fcb6910a0363c", null ],
    [ "previous_precision_base", "namespacegko.html#a7f9e0f5413aca83838f94cbe9863e15c", null ],
    [ "reduce_precision", "namespacegko.html#a87a96a1b78352538d905c10518bf5571", null ],
    [ "remove_complex", "namespacegko.html#a107302a750bfa82a2107c77293f791c9", null ],
    [ "size_type", "namespacegko.html#a9579c98b1d85bf4ad02d7cb5b96fc771", null ],
    [ "to_complex", "namespacegko.html#a4ad20e5381a84928753efde0b2bc7f85", null ],
    [ "to_real", "namespacegko.html#ad6b4f42aaf509f2f3660fcba0d230cac", null ],
    [ "truncate_type", "namespacegko.html#a37e3f42c8d971e4e8cb0cc43c88eea65", null ],
    [ "uint16", "namespacegko.html#af07ab7e285d68cde5e10f9c4ed642213", null ],
    [ "uint32", "namespacegko.html#a7cf056fa904140b50658e0637fba428c", null ],
    [ "uint64", "namespacegko.html#a09ee89da532d8b1fa6fdecec2d20b9bf", null ],
    [ "uint8", "namespacegko.html#a06d96f1ecdca6b86399173969771c3fb", null ],
    [ "uintptr", "namespacegko.html#a70648f1299a0c1297e2bf86f47264626", null ],
    [ "allocation_mode", "namespacegko.html#afbed8e2cbd3ee4ca962e12f688858bdb", null ],
    [ "layout_type", "namespacegko.html#ae749a5ea11a93c1bcc9158d9a6e9fb68", [
      [ "array", "namespacegko.html#ae749a5ea11a93c1bcc9158d9a6e9fb68af1f713c9e000f5d3f280adbd124df4f5", null ],
      [ "coordinate", "namespacegko.html#ae749a5ea11a93c1bcc9158d9a6e9fb68af5d7aa3ba4929cc12dc51a92c59fabd3", null ]
    ] ],
    [ "log_propagation_mode", "namespacegko.html#aa2543f42cbbe1a9373dc46d04c112bee", [
      [ "never", "namespacegko.html#aa2543f42cbbe1a9373dc46d04c112beeac7561db7a418dd39b2201dfe110ab4a4", null ],
      [ "automatic", "namespacegko.html#aa2543f42cbbe1a9373dc46d04c112beea2bd9c0ed00116be1258e0cc66617d7c8", null ]
    ] ],
    [ "abs", "namespacegko.html#a0cb7d0ece3444fcf3a7ebd82e1cb0a69", null ],
    [ "as", "namespacegko.html#a6e42260dd30f8bd5c4a28fa49b0fca49", null ],
    [ "as", "namespacegko.html#a3c360489a4f78b1fc92f75f27b3b7e13", null ],
    [ "as", "namespacegko.html#a2f94c3fc158c7bed4506a5fa03746e09", null ],
    [ "as", "namespacegko.html#a962c3722ef8395c17a374ddbcb9cbb50", null ],
    [ "as", "namespacegko.html#a5949df0b865aea945843bfac6946831a", null ],
    [ "as", "namespacegko.html#a6d9d11fc6d039b7715a96d3ef9841898", null ],
    [ "as", "namespacegko.html#ae3e355a655feea026a7c46814d37a9c9", null ],
    [ "ceildiv", "namespacegko.html#a93065a86872e6511b701b73b75823483", null ],
    [ "clone", "namespacegko.html#aa194e34282452493231ca7b01ffb5e64", null ],
    [ "clone", "namespacegko.html#a7412910f84951c1a23563e758eb01282", null ],
    [ "conj", "namespacegko.html#ad79fd5c1fb85403796c40c0a916a15f2", null ],
    [ "convert_to", "namespacegko.html#a7cb327baf9ca9018d06fa5554464d29d", null ],
    [ "copy_and_convert_to", "namespacegko.html#ae27269c18937d9a8866b431aff94433e", null ],
    [ "copy_and_convert_to", "namespacegko.html#ab6954ded2bc4730777068facde07983a", null ],
    [ "copy_and_convert_to", "namespacegko.html#a2c02ca75c7c97c556424bc2996510c83", null ],
    [ "copy_and_convert_to", "namespacegko.html#ae4916d7f4a38162b665935d0adfb3825", null ],
    [ "get_significant_bit", "namespacegko.html#a4eea40e4123a3fdb60fcd92f902c6d6d", null ],
    [ "get_superior_power", "namespacegko.html#ad39645fe8148a8a812a9528865a77600", null ],
    [ "give", "namespacegko.html#abc3b2c363d6eb3d9837a6d9efa589844", null ],
    [ "imag", "namespacegko.html#a795f649e3744fbfe128aec0b0f928aaa", null ],
    [ "initialize", "group__LinOp.html#ga698f7e43f788413f45a6e91fd65d0c1e", null ],
    [ "initialize", "group__LinOp.html#ga70851b4c3c9b01bb667b3a8e438fb6d2", null ],
    [ "initialize", "group__LinOp.html#ga858a8403f19e76ac1ded3c154a91d7eb", null ],
    [ "initialize", "group__LinOp.html#ga97de1557afe54a2e9013f9f95f290387", null ],
    [ "invalid_index", "namespacegko.html#afec01a3afbf68d99fc0f886c51bdc713", null ],
    [ "is_complex", "namespacegko.html#a9b3e79911bb6145d7ba865dbe436b915", null ],
    [ "is_complex_or_scalar", "namespacegko.html#a6881ebae53e15cb88342c0540d953f59", null ],
    [ "is_finite", "namespacegko.html#aafd1826b8d8325e5eadec7c9568dbc14", null ],
    [ "is_finite", "namespacegko.html#a01e4cc92b86977c60de3fe3ee991fa40", null ],
    [ "is_nan", "namespacegko.html#acff21f04b9f0d01bf5fc5d8da3d939e0", null ],
    [ "is_nan", "namespacegko.html#a6f943e1343264921351afce70b33009a", null ],
    [ "is_nonzero", "namespacegko.html#aef9b29733e6eb45475a2b84f79a6d012", null ],
    [ "is_zero", "namespacegko.html#a785976e6dbc9d8511325617ca46040bf", null ],
    [ "lend", "namespacegko.html#acc4ed16c876310fd8cffaca4d6c62664", null ],
    [ "lend", "namespacegko.html#aa011422ea11684b8b3121058cd6f8933", null ],
    [ "make_array_view", "namespacegko.html#a752922d291cf7c72e3042cc5b367aa60", null ],
    [ "make_const_array_view", "namespacegko.html#a5309c321872a54fc9818ed9f5556eef4", null ],
    [ "make_const_dense_view", "namespacegko.html#a218d2e44e2d95fbe638ad98789fccb07", null ],
    [ "make_dense_view", "namespacegko.html#a6d2de0c8ecbe3736e7d201e6a372be02", null ],
    [ "make_temporary_clone", "namespacegko.html#adf2f8602dc9453752a787b40bbf13fcf", null ],
    [ "make_temporary_conversion", "namespacegko.html#a53160e02553fceb89af3e58435de2aca", null ],
    [ "make_temporary_output_clone", "namespacegko.html#a64c4f7d1a2e86dafc644d9d96f7f4514", null ],
    [ "max", "namespacegko.html#af1812df45c6ec07780d579a12b64c753", null ],
    [ "min", "namespacegko.html#aaaf8487194bcb40b528969c187a413a0", null ],
    [ "mixed_precision_dispatch", "namespacegko.html#a205901dcce27e1df970c569d46d87551", null ],
    [ "mixed_precision_dispatch_real_complex", "namespacegko.html#a3b9785eed86179e15b8fb4e74f7e9f89", null ],
    [ "move_to", "namespacegko.html#a6fcc3453bf500454b56a5f2f196b871c", null ],
    [ "nan", "namespacegko.html#a2d8c25cb4bc4a661a986b5cae340c96b", null ],
    [ "nan", "namespacegko.html#a70bf9f2c62b689f4f7e074392be0f828", null ],
    [ "one", "namespacegko.html#a0059e27f8f4bc348ff65c1e60caf47c8", null ],
    [ "one", "namespacegko.html#ab4f16ecf0a759f46259cf9518f1e4568", null ],
    [ "operator!=", "namespacegko.html#accf6e6291e57abe8d7d05968666a42e0", null ],
    [ "operator!=", "namespacegko.html#a61d408b4cd77aae6cac7a40c8307fddb", null ],
    [ "operator<<", "namespacegko.html#a48951a7770f9167cbb1e8e199a98dfab", null ],
    [ "operator<<", "namespacegko.html#a95f2df4e14987d3f8c17e90ea9d8d48a", null ],
    [ "operator==", "namespacegko.html#ad1f668258612e583add058f77ff91be3", null ],
    [ "operator==", "namespacegko.html#a4dbafa6e062c2036991ec8c3f6b201cf", null ],
    [ "pi", "namespacegko.html#a0603ce0a60183a6698ac9b523694fb68", null ],
    [ "precision_dispatch", "namespacegko.html#a3c46f1caf8135f7492aa83d9ac3bc83e", null ],
    [ "precision_dispatch_real_complex", "namespacegko.html#aaebbe93d733274398213df2d3acf1b79", null ],
    [ "precision_dispatch_real_complex", "namespacegko.html#a24dd55a9e5d991204024c68a501cdb3e", null ],
    [ "precision_dispatch_real_complex", "namespacegko.html#a98c5a37c89e32c0f2b567f8e73870e3a", null ],
    [ "read", "namespacegko.html#abc58509ecdcb48399e12f9a081ed7545", null ],
    [ "read_binary", "namespacegko.html#a06b6aa3ec2d20b977d8730cc9cfdafd8", null ],
    [ "read_binary_raw", "namespacegko.html#a5e379ed0d74e7c7f8c33fbfe6816e697", null ],
    [ "read_generic", "namespacegko.html#a3c49cd22dbd4f0fa54597a950a145b63", null ],
    [ "read_generic_raw", "namespacegko.html#a70492b519a55d1d62a3a11f6b297ecd9", null ],
    [ "read_raw", "namespacegko.html#afddd8179d8034cce9a2f7e02bae33fd7", null ],
    [ "real", "namespacegko.html#af21648097306adbabc6234b4609ce297", null ],
    [ "reduce_add", "namespacegko.html#a718bb2876f514b73c900f72fcc9d464e", null ],
    [ "reduce_add", "namespacegko.html#a12e62081e2511f958dc2c9f1cc73c11d", null ],
    [ "round_down", "namespacegko.html#a8f5c64893cb6241b6c91c3aad724158f", null ],
    [ "round_up", "namespacegko.html#a1a24c8b8654e0027471eee100e76e639", null ],
    [ "safe_divide", "namespacegko.html#aa1470fdc2a75dcda76bea4b879a29886", null ],
    [ "share", "namespacegko.html#ae99fdd8bfa5ac694adcb7297d432967e", null ],
    [ "squared_norm", "namespacegko.html#abbb55709b10d707b2cbef803832aa834", null ],
    [ "transpose", "namespacegko.html#aacad7f87b38d3f26674ed034d442a1a0", null ],
    [ "transpose", "namespacegko.html#a471f1b79842d9b7e2e97d10d2eef5fee", null ],
    [ "unit_root", "namespacegko.html#a7d18aa213befc4d1dac5dbc8eeed6e7d", null ],
    [ "with_matrix_type", "namespacegko.html#a537803d962d07cf43e1e0cbc9f6a3f8b", null ],
    [ "write", "namespacegko.html#abc28c235c3fbbf3c495b1850c61746d2", null ],
    [ "write", "namespacegko.html#af82d8f7795fefcf5f38a38895e316c02", null ],
    [ "write_binary", "namespacegko.html#aba9ca89ef08421197d3dbf84b0ad884c", null ],
    [ "write_binary_raw", "namespacegko.html#a3b27a0c0282115116c160884dc0a9468", null ],
    [ "write_raw", "namespacegko.html#a2d4b63ce98a16dc2c48aacd534a7b8ba", null ],
    [ "zero", "namespacegko.html#a70dbe01ff95c7b953d3d737424c6feb5", null ],
    [ "zero", "namespacegko.html#a9f1cd7be946b9a2c15b01b744cf3e732", null ],
    [ "byte_size", "namespacegko.html#acae2e648052ec788bd8ba9e0192652a6", null ]
];